// LanMgr.h: interface for the TLanMgr class.
//

#if !defined(_LANMGR_H_)
#define _LANMGR_H_

#if _MSC_VER >= 1000
#pragma once
#endif // _MSC_VER >= 1000

#ifndef __AFXWIN_H__
	#error include 'stdafx.h' before including this file for PCH
#endif


#undef DECL
#ifdef UTILS_DLL
#define DECL _declspec(dllexport)
#else
#define DECL _declspec(dllimport)
#endif


#define INVALID_LAN_HANDLE ((HANDLE)(0xFFFFFFFF))
#define MAX_LAN_HANDLES (sizeof(DWORD) * 8)


//////////////////////////////////////////////////////////////////////
// TLanMgr Class
//
//    A single static instance of this class keeps track of who has 
//    turned Lan on, both for the current session, and at boot. 
//    Typical usage...
//
//       HANDLE h = LanMgr.CreateHandle(_T("MyName")); 
//       if (h != INVALID_LAN_HANDLE)
//       {
//          // Now turn LAN on and off as desired...
//          LanMgr.TurnLanOn(h);
//          LanMgr.TurnLanOnAtBoot(h);
//          ...   
//          LanMgr.TurnLanOff(h);
//          LanMgr.TurnLanOffAtBoot(h);
//          
//          // When finished (no more need to control lan on/off), 
//          // then close the handle. 
//          LanMgr.CloseHandle(h);
//       }
//    

class DECL TLanMgr
{
   ////////////////////////////////
   // Interface
   ////////////////////////////////
   public:
   
   // Constructors and destructor.
   TLanMgr();
   virtual ~TLanMgr();

   virtual HANDLE CreateHandle(const CString& strUser);
   virtual void CloseHandle(HANDLE h);
   virtual bool TurnLanOn(HANDLE h);
   // Returns first IP address found from any installed Ethernet device
   virtual CString GetIPAddress();
   // Waits for first IP address found from any installed Ethernet device, up to dwWait MS
   CString WaitForIPAddress(DWORD dwWait = 20000);
   virtual bool TurnLanOff(HANDLE h);
   virtual bool ChangeName(HANDLE h, const CString& strName);
   
   // Returns a comma-separated list of the names of users who have 
   // requested the LAN be turned on (for current session, not at boot). 
   virtual CString GetUserList();

   // These do NOT support voting, i.e., last one called wins. Hence, no 
   // handle is required. 
   virtual void TurnLanOnAtBoot();
   virtual void TurnLanOnWhenConnect();
   virtual void TurnLanOffAtBoot();
   virtual bool GetBootSetting() {return m_bOnAtBoot;};
   virtual bool GetConnectSetting() {return m_bOnWhenConnect;};
   CString GetPowerState();
   bool IsOn() {return GetPowerState() == _T("On");}
   bool IsOff() {return GetPowerState() == _T("Off");}
   bool IsAuto() {return GetPowerState() == _T("Auto");}
   
   ////////////////////////////////
   // Implementation
   ////////////////////////////////
   protected:

   CRITICAL_SECTION m_cs;
   DWORD m_dwHandlesAllocated;
   DWORD m_dwUserMask;
   CString m_strUsers[MAX_LAN_HANDLES];
   bool m_bOnAtBoot;
   bool m_bOnWhenConnect;
};


extern DECL TLanMgr LanMgr; 


#endif // !defined(_LANMGR_H_)
